@@ -72,9 +72,10 @@ import typing_extensions
 
 from ._jsii import *
 
+import aws_cdk
 import aws_cdk.aws_kms
 import aws_cdk.aws_s3
-import aws_cdk.core
+import constructs
 
 
 class PrivateBucket(
@@ -84,7 +85,7 @@ class PrivateBucket(
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         access_control: typing.Optional[aws_cdk.aws_s3.BucketAccessControl] = None,
@@ -103,7 +104,7 @@ class PrivateBucket(
         metrics: typing.Optional[typing.Sequence[aws_cdk.aws_s3.BucketMetrics]] = None,
         object_ownership: typing.Optional[aws_cdk.aws_s3.ObjectOwnership] = None,
         public_read_access: typing.Optional[builtins.bool] = None,
-        removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy] = None,
+        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
         server_access_logs_bucket: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         server_access_logs_prefix: typing.Optional[builtins.str] = None,
         transfer_acceleration: typing.Optional[builtins.bool] = None,
@@ -224,7 +225,7 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         metrics: typing.Optional[typing.Sequence[aws_cdk.aws_s3.BucketMetrics]] = None,
         object_ownership: typing.Optional[aws_cdk.aws_s3.ObjectOwnership] = None,
         public_read_access: typing.Optional[builtins.bool] = None,
-        removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy] = None,
+        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
         server_access_logs_bucket: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         server_access_logs_prefix: typing.Optional[builtins.str] = None,
         transfer_acceleration: typing.Optional[builtins.bool] = None,
@@ -501,13 +502,13 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def removal_policy(self) -> typing.Optional[aws_cdk.core.RemovalPolicy]:
+    def removal_policy(self) -> typing.Optional[aws_cdk.RemovalPolicy]:
         '''Policy to apply when the bucket is removed from this stack.
 
         :default: - The bucket will be orphaned.
         '''
         result = self._values.get("removal_policy")
-        return typing.cast(typing.Optional[aws_cdk.core.RemovalPolicy], result)
+        return typing.cast(typing.Optional[aws_cdk.RemovalPolicy], result)
 
     @builtins.property
     def server_access_logs_bucket(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
